import logging
import os
import sys
import urllib

from yum.plugins import TYPE_CORE
from yum.yumRepo import YumRepository
from yum import config
from yum import logginglevels
import yum.Errors
import subprocess

URL_SCHEME = 'https://'
__revision__ = "1.0.0"
requires_api_version = '2.5'
plugin_type = TYPE_CORE

def config_hook(conduit):
    logger = logging.getLogger("yum.verbose.main")
    yum.config.RepoConf.rk_repo = yum.config.Option()


def parse_url(url):
    if url.startswith(URL_SCHEME) and len(url) > len(URL_SCHEME):
       rk_repo_and_uuid = url.rstrip('/')[len(URL_SCHEME):].split('/', 1)
       if len(rk_repo_and_uuid) == 1:
          rk_repo_and_uuid.append('')
       return rk_repo_and_uuid
    return (None, None)

def get_key(uuid):
    proc = subprocess.Popen(['/usr/sbin/vz-get-rk', uuid],
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                close_fds=True)
    out, _ = proc.communicate()
    proc.wait()
    if out:
        return out
    else:
        return uuid

def prereposetup_hook(conduit):
    for repo in conduit.getRepos().listEnabled():
        if isinstance(repo, YumRepository) and repo.rk_repo and repo.isEnabled():
           urls = []
           for url in repo.urls:
               url_string, uuid = parse_url(url)
               if url_string and uuid:
                   urls.append('https://' + url_string + '/' + get_key(uuid))
           repo.urls = urls if urls else ["file:///var/spool/yum-plugin-rk-repo",]
